==> transmedika_one_to_one_call-1.0.22.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:transmedika_one_to_one_call/webrtc/one_to_one_page.dart';
import 'package:transmedika_one_to_one_call/webrtc/profile.dart';

class MyHttpOverrides extends HttpOverrides {
  @override
  HttpClient createHttpClient(SecurityContext? context){
    return super.createHttpClient(context)
      ..badCertificateCallback = (X509Certificate cert, String host, int port)=> true;
  }
}

void main() {
  HttpOverrides.global = MyHttpOverrides();
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});
  @override
  Widget build(BuildContext context) {

    Profile mySelf = Profile(
        email: "maman@rskp.com",
        fullName: 'TN, MAMAN',
        uuid: '7bfb1588-fc6a-4878-a96f-126cd6a6692c',
        profilePicture: null
    );

    Profile other = Profile(
        email: "dion@rskp.com",
        fullName: 'dr. Dionisius Panji Wijanarko, Sp.B',
        uuid: '42c6145f-8143-4d67-ad30-6f84571e0f65',
        profilePicture: null
    );

    String consultationId = '224';

    /// Fcm token bisa kamu dapat dari request GET ke endpoint ini auth/check-device-id-multiple,
    /// Fcm token hanya digunakan jika kamu ingin menelepon saja, jadi optional
    /// OneToOneScreen(
    ///    mySelf: mySelf,
    ///    other: other,
    ///    consultationId: consultationId,
    ///    fcmTokens: fcmTokens
    ///  )
    List<String> fcmTokens = ['fYSu5ILSvcKFUwyPRo--kl:APA91bF7c3EVBX7jvGvhQZrFC-Y2t83sjZ79gljq03WE9finRILE608KHAZkrX0MRIjAZL2Fi2Cvy1orZY8C9sgNfTH_eHWJl0X7quGSyusbTDaCnwVtGuwT22H3PbQwhaPmAXgqX6Oq'];


    /// untuk menerima panggilan kamu cukup isi paramter construktor
    /// OneToOneScreen(
    ///    mySelf: mySelf,
    ///    other: other,
    ///    consultationId: consultationId
    ///  )
    /// untuk menerima panggilan mekanismenya aplikasi kamu akan menerima notifikasi, data myself, other, consultationId bisa kamu dapatkan
    /// dari data yang dikirim lewat notifikasi


    return MaterialApp(
        title: 'Flutter Demo',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: OneToOneScreen(
          mySelf: mySelf,
          other: other,
          consultationId: consultationId
        )
    );
  }
}

==> transmedika_one_to_one_call-1.0.33.tar.gz: example/lib/main.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:transmedika_one_to_one_call/webrtc/one_to_one_page.dart';


class MyHttpOverrides extends HttpOverrides {
  @override
  HttpClient createHttpClient(SecurityContext? context){
    return super.createHttpClient(context)
      ..badCertificateCallback = (X509Certificate cert, String host, int port)=> true;
  }
}

void main() {
  HttpOverrides.global = MyHttpOverrides();
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {

    final mySelf = {
      'email': "maman@rskp.com",
      'name': 'TN, MAMAN',
      'uuid': '7bfb1588-fc6a-4878-a96f-126cd6a6692c',
      'profilePicture': 'https://upload.wikimedia.org/wikipedia/commons/0/04/Elon_Musk_and_Hans_Koenigsmann_at_the_SpaceX_CRS-8_post-launch_press_conference_%2826223624532%29_%28cropped%29.jpg',
      'token': 'xxxxxxxxxxxx'
    };

    final other = {
      'email': "dion@rskp.com",
      'name': 'dr. Dionisius Panji Wijanarko, Sp.B',
      'uuid': '42c6145f-8143-4d67-ad30-6f84571e0f65',
      'profilePicture': 'https://upload.wikimedia.org/wikipedia/commons/thumb/5/56/Donald_Trump_official_portrait.jpg/710px-Donald_Trump_official_portrait.jpg',
    };

    String consultationId = '224';

    /// Fcm token bisa kamu dapat dari request GET ke endpoint ini auth/check-device-id-multiple,
    /// Fcm token hanya digunakan jika kamu ingin menelepon saja, jadi optional
    /// OneToOneScreen(
    ///    mySelf: mySelf,
    ///    other: other,
    ///    consultationId: consultationId,
    ///    fcmTokens: fcmTokens
    ///  )
    List<String> fcmTokens = ['fYSu5ILSvcKFUwyPRo--kl:APA91bF7c3EVBX7jvGvhQZrFC-Y2t83sjZ79gljq03WE9finRILE608KHAZkrX0MRIjAZL2Fi2Cvy1orZY8C9sgNfTH_eHWJl0X7quGSyusbTDaCnwVtGuwT22H3PbQwhaPmAXgqX6Oq'];


    /// untuk menerima panggilan kamu cukup isi paramter construktor
    /// OneToOneScreen(
    ///    mySelf: mySelf,
    ///    other: other,
    ///    consultationId: consultationId
    ///  )
    /// untuk menerima panggilan mekanismenya aplikasi kamu akan menerima notifikasi, data myself, other, consultationId bisa kamu dapatkan
    /// dari data yang dikirim lewat notifikasi


    return MaterialApp(
        title: 'Flutter Demo',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: OneToOneScreen(
          mySelf: mySelf,
          other: other,
          consultationId: consultationId,
          fcmTokens: fcmTokens,
          onMessage: (message){
            ///put your toast or widget for display message
          },
        )
    );
  }
}
